port = 2628 # default port
timeout = 60 # timeout for connection, in seconds

# debugging level
# anything except 0 means print debug messages
debuglevel = 0

# name of logfile - leave blank for stderr
#logfile = ''
logfile = '/var/log/serpento.log'

# directory to put cache files into
cachedir = '/var/cache/serpento'

